@@ -36,7 +36,7 @@ class Object
   end
 
 
-  def _name2simbol( arg )
+  def _name2sym( arg )
     if arg.respond_to? :id2name then
       arg
     else
@@ -44,7 +44,7 @@ class Object
     end
   end
 
-  def _type2simbol( arg )
+  def _type2sym( arg )
     if arg.respond_to? :id2name then
       arg
     else
@@ -52,4 +52,8 @@ class Object
     end
   end
 
+  # 'simbol' is typo
+  alias _name2simbol _name2sym
+  alias _type2simbol _type2sym
+
 end
