@@ -42,7 +42,7 @@ module Racc
       Racc_YY_Parse_Method      = :_racc_yyparse_rb
     end
 
-    Racc_ruby_parser_version = '1.3.5'
+    Racc_ruby_parser_version = '1.3.7'
     Racc_parser_version = Racc_ruby_parser_version
 
     def self.racc_runtime_type
@@ -108,7 +108,7 @@ module Racc
       reduce_n,     use_result    = arg
 
       _racc_init_sysvars
-      act = i = nil
+      tok = act = i = nil
       nerr = 0
 
 
@@ -117,9 +117,13 @@ module Racc
 
         if i = action_pointer[ @racc_state[-1] ] then
           if @racc_read_next then
-            if @racc_t != 0 then   # $
+            if @racc_t != 0 then   # not EOF
               tok, @racc_val = next_token()
-              @racc_t = (token_table[tok] or 1)   # error token
+              unless tok then   # EOF
+                @racc_t = 0
+              else
+                @racc_t = (token_table[tok] or 1)   # error token
+              end
               racc_read_token( @racc_t, tok, @racc_val ) if @yydebug
 
               @racc_read_next = false
@@ -128,7 +132,7 @@ module Racc
           i += @racc_t
           if i >= 0 and act = action_table[i] and
              action_check[i] == @racc_state[-1] then
-             ;
+            ;
           else
             act = action_default[ @racc_state[-1] ]
           end
@@ -172,8 +176,12 @@ module Racc
 
         recv.__send__( mid ) do |tok, val|
 # $stderr.puts "rd: tok=#{tok}, val=#{val}"
+          unless tok then
+            @racc_t = 0
+          else
+            @racc_t = (token_table[tok] or 1)   # error token
+          end
           @racc_val = val
-          @racc_t = (token_table[tok] or 1)   # error token
           @racc_read_next = false
 
           i += @racc_t
@@ -360,7 +368,9 @@ nerr = 0   # tmp
     end
 
     def on_error( t, val, vstack )
-      raise ParseError, "\nparse error on value #{val.inspect}"
+      raise ParseError, sprintf("\nparse error on value %s (%s)",
+                                val.inspect,
+                                token_to_str(t) || '?')
     end
 
     def yyerror
@@ -380,7 +390,7 @@ nerr = 0   # tmp
 
     def racc_read_token( t, tok, val )
       @racc_debug_out.print 'read    '
-      @racc_debug_out.print tok.inspect, '(internaly ', racc_token2str(t), ') '
+      @racc_debug_out.print tok.inspect, '(', racc_token2str(t), ') '
       @racc_debug_out.puts val.inspect
       @racc_debug_out.puts
     end
@@ -444,6 +454,10 @@ nerr = 0   # tmp
         raise RuntimeError, "[Racc Bug] can't convert token #{tok} to string"
     end
 
+    def token_to_str( t )
+      type::Racc_token_to_s_table[t]
+    end
+
   end
 
 end
