@@ -17,7 +17,7 @@ module TMail
 
   class Parser < ::Racc::Parser
 
-module_eval <<'..end mailp.y modeval..idbd91c15b7d', 'mailp.y', 290
+module_eval <<'..end mp.y modeval..idbe768b6ee8', 'mp.y', 290
 
   def self.parse( str, obj, ident )
     new.parse( str, obj, ident )
@@ -110,7 +110,7 @@ module_eval <<'..end mailp.y modeval..idbd91c15b7d', 'mailp.y', 290
       arr.push mdata[1]
     end
     str.strip!
-    arr.push unless str.empty?
+    arr.push str unless str.empty?
   end
 
 
@@ -122,9 +122,9 @@ module_eval <<'..end mailp.y modeval..idbd91c15b7d', 'mailp.y', 290
     end
   end
 
-..end mailp.y modeval..idbd91c15b7d
+..end mp.y modeval..idbe768b6ee8
 
-##### racc 1.3.6 generates ###
+##### racc 1.3.7 generates ###
 
 racc_reduce_table = [
  0, 0, :racc_error,
@@ -467,13 +467,94 @@ Racc_arg = [
  racc_reduce_n,
  racc_use_result_var ]
 
+Racc_token_to_s_table = [
+'$end',
+'error',
+'DateH',
+'RecvH',
+'RetpathH',
+'MaddrH',
+'SaddrH',
+'MmboxH',
+'SmboxH',
+'MsgidH',
+'KeyH',
+'EncH',
+'VersionH',
+'CTypeH',
+'CEncodingH',
+'CDispositionH',
+'Mbox',
+'Spec',
+'DIGIT',
+'ATOM',
+'","',
+'":"',
+'FROM',
+'"@"',
+'DOMLIT',
+'BY',
+'VIA',
+'WITH',
+'ID',
+'FOR',
+'";"',
+'"<"',
+'">"',
+'"."',
+'QUOTED',
+'TOKEN',
+'"/"',
+'"="',
+'$start',
+'content',
+'datetime',
+'received',
+'returnpath',
+'addrs',
+'addr',
+'mboxes',
+'mbox',
+'msgid',
+'keys',
+'enc',
+'version',
+'ctype',
+'cencode',
+'cdisp',
+'spec',
+'day',
+'hour',
+'zone',
+'from',
+'by',
+'via',
+'with',
+'id',
+'for',
+'recvdatetime',
+'domain',
+'routeaddr',
+'group',
+'phrase',
+'route',
+'at_domains',
+'local',
+'word',
+'domword',
+'atom',
+'params',
+'value',
+'disp_params',
+'disp_param']
+
 Racc_debug_parser = false
 
 ##### racc system variables end #####
 
  # reduce 0 omitted
 
-module_eval <<'.,.,', 'mailp.y', 14
+module_eval <<'.,.,', 'mp.y', 14
   def _reduce_1( val, _values, result )
  @field.date  = val[1]
    result
@@ -484,42 +565,42 @@ module_eval <<'.,.,', 'mailp.y', 14
 
  # reduce 3 omitted
 
-module_eval <<'.,.,', 'mailp.y', 17
+module_eval <<'.,.,', 'mp.y', 17
   def _reduce_4( val, _values, result )
  @field.addrs.replace val[1]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 18
+module_eval <<'.,.,', 'mp.y', 18
   def _reduce_5( val, _values, result )
  @field.addr  = val[1]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 19
+module_eval <<'.,.,', 'mp.y', 19
   def _reduce_6( val, _values, result )
  @field.addrs.replace val[1]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 20
+module_eval <<'.,.,', 'mp.y', 20
   def _reduce_7( val, _values, result )
  @field.addr  = val[1]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 21
+module_eval <<'.,.,', 'mp.y', 21
   def _reduce_8( val, _values, result )
  @field.msgid = val[1]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 22
+module_eval <<'.,.,', 'mp.y', 22
   def _reduce_9( val, _values, result )
  @field.keys.replace val[1]
    result
@@ -536,7 +617,7 @@ module_eval <<'.,.,', 'mailp.y', 22
 
  # reduce 14 omitted
 
-module_eval <<'.,.,', 'mailp.y', 30
+module_eval <<'.,.,', 'mp.y', 30
   def _reduce_15( val, _values, result )
                   mb = val[1]
                   @field.phrase = mb.phrase
@@ -547,7 +628,7 @@ module_eval <<'.,.,', 'mailp.y', 30
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 38
+module_eval <<'.,.,', 'mp.y', 38
   def _reduce_16( val, _values, result )
                   mb = val[1]
                   @field.local  = mb.local
@@ -556,7 +637,7 @@ module_eval <<'.,.,', 'mailp.y', 38
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 47
+module_eval <<'.,.,', 'mp.y', 47
   def _reduce_17( val, _values, result )
                   t = Time.gm( val[3].to_i, val[2], val[1].to_i, 0, 0, 0 )
                   result = (t + val[4] - val[5]).localtime
@@ -568,7 +649,7 @@ module_eval <<'.,.,', 'mailp.y', 47
 
  # reduce 19 omitted
 
-module_eval <<'.,.,', 'mailp.y', 56
+module_eval <<'.,.,', 'mp.y', 56
   def _reduce_20( val, _values, result )
                   result = (val[0].to_i * 60 * 60) +
                            (val[2].to_i * 60)
@@ -576,7 +657,7 @@ module_eval <<'.,.,', 'mailp.y', 56
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 61
+module_eval <<'.,.,', 'mp.y', 61
   def _reduce_21( val, _values, result )
                   result = (val[0].to_i * 60 * 60) +
                            (val[2].to_i * 60) +
@@ -585,7 +666,7 @@ module_eval <<'.,.,', 'mailp.y', 61
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 68
+module_eval <<'.,.,', 'mp.y', 68
   def _reduce_22( val, _values, result )
                   result = ::TMail.zonestr2i( result )
    result
@@ -596,21 +677,21 @@ module_eval <<'.,.,', 'mailp.y', 68
 
  # reduce 24 omitted
 
-module_eval <<'.,.,', 'mailp.y', 76
+module_eval <<'.,.,', 'mp.y', 76
   def _reduce_25( val, _values, result )
                   @field.from = Address.join( val[1] )
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 80
+module_eval <<'.,.,', 'mp.y', 80
   def _reduce_26( val, _values, result )
                   @field.from = Address.join( val[3] )
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 84
+module_eval <<'.,.,', 'mp.y', 84
   def _reduce_27( val, _values, result )
                   @field.from = Address.join( val[1] )
    result
@@ -619,7 +700,7 @@ module_eval <<'.,.,', 'mailp.y', 84
 
  # reduce 28 omitted
 
-module_eval <<'.,.,', 'mailp.y', 90
+module_eval <<'.,.,', 'mp.y', 90
   def _reduce_29( val, _values, result )
                   @field.by = Address.join( val[1] )
    result
@@ -628,7 +709,7 @@ module_eval <<'.,.,', 'mailp.y', 90
 
  # reduce 30 omitted
 
-module_eval <<'.,.,', 'mailp.y', 96
+module_eval <<'.,.,', 'mp.y', 96
   def _reduce_31( val, _values, result )
                   @field.via = val[1]
    result
@@ -637,7 +718,7 @@ module_eval <<'.,.,', 'mailp.y', 96
 
  # reduce 32 omitted
 
-module_eval <<'.,.,', 'mailp.y', 102
+module_eval <<'.,.,', 'mp.y', 102
   def _reduce_33( val, _values, result )
                   @field.with.push val[1]
    result
@@ -646,14 +727,14 @@ module_eval <<'.,.,', 'mailp.y', 102
 
  # reduce 34 omitted
 
-module_eval <<'.,.,', 'mailp.y', 108
+module_eval <<'.,.,', 'mp.y', 108
   def _reduce_35( val, _values, result )
                   @field.msgid = val[1]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 112
+module_eval <<'.,.,', 'mp.y', 112
   def _reduce_36( val, _values, result )
                   @field.msgid = val[1]
    result
@@ -662,7 +743,7 @@ module_eval <<'.,.,', 'mailp.y', 112
 
  # reduce 37 omitted
 
-module_eval <<'.,.,', 'mailp.y', 118
+module_eval <<'.,.,', 'mp.y', 118
   def _reduce_38( val, _values, result )
                   @field.for_ = val[1].address
    result
@@ -671,7 +752,7 @@ module_eval <<'.,.,', 'mailp.y', 118
 
  # reduce 39 omitted
 
-module_eval <<'.,.,', 'mailp.y', 125
+module_eval <<'.,.,', 'mp.y', 125
   def _reduce_40( val, _values, result )
                   @field.date = val[1]
    result
@@ -680,7 +761,7 @@ module_eval <<'.,.,', 'mailp.y', 125
 
  # reduce 41 omitted
 
-module_eval <<'.,.,', 'mailp.y', 131
+module_eval <<'.,.,', 'mp.y', 131
   def _reduce_42( val, _values, result )
                   @field.route.replace result.route
                   @field.addr = result.addr
@@ -688,14 +769,14 @@ module_eval <<'.,.,', 'mailp.y', 131
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 135
+module_eval <<'.,.,', 'mp.y', 135
   def _reduce_43( val, _values, result )
  result = val
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 136
+module_eval <<'.,.,', 'mp.y', 136
   def _reduce_44( val, _values, result )
  result.push val[2]
    result
@@ -706,14 +787,14 @@ module_eval <<'.,.,', 'mailp.y', 136
 
  # reduce 46 omitted
 
-module_eval <<'.,.,', 'mailp.y', 143
+module_eval <<'.,.,', 'mp.y', 143
   def _reduce_47( val, _values, result )
                   result = val
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 147
+module_eval <<'.,.,', 'mp.y', 147
   def _reduce_48( val, _values, result )
                   result.push val[2]
    result
@@ -724,7 +805,7 @@ module_eval <<'.,.,', 'mailp.y', 147
 
  # reduce 50 omitted
 
-module_eval <<'.,.,', 'mailp.y', 154
+module_eval <<'.,.,', 'mp.y', 154
   def _reduce_51( val, _values, result )
                   val[1].phrase = HFdecoder.decode( result )
                   result = val[1]
@@ -732,14 +813,14 @@ module_eval <<'.,.,', 'mailp.y', 154
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 160
+module_eval <<'.,.,', 'mp.y', 160
   def _reduce_52( val, _values, result )
                   result = AddressGroup.new( result, val[2] )
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 166
+module_eval <<'.,.,', 'mp.y', 166
   def _reduce_53( val, _values, result )
                   result = val[2]
                   result.route = val[1]
@@ -747,7 +828,7 @@ module_eval <<'.,.,', 'mailp.y', 166
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 171
+module_eval <<'.,.,', 'mp.y', 171
   def _reduce_54( val, _values, result )
                   result = val[1]
    result
@@ -756,56 +837,56 @@ module_eval <<'.,.,', 'mailp.y', 171
 
  # reduce 55 omitted
 
-module_eval <<'.,.,', 'mailp.y', 176
+module_eval <<'.,.,', 'mp.y', 176
   def _reduce_56( val, _values, result )
  result = [ val[1] ]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 177
+module_eval <<'.,.,', 'mp.y', 177
   def _reduce_57( val, _values, result )
  result.push val[3]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 179
+module_eval <<'.,.,', 'mp.y', 179
   def _reduce_58( val, _values, result )
  result = Address.new( val[0], val[2] )
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 180
+module_eval <<'.,.,', 'mp.y', 180
   def _reduce_59( val, _values, result )
  result = Address.new( result, nil )
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 182
+module_eval <<'.,.,', 'mp.y', 182
   def _reduce_60( val, _values, result )
  result = val
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 183
+module_eval <<'.,.,', 'mp.y', 183
   def _reduce_61( val, _values, result )
  result.push val[2]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 185
+module_eval <<'.,.,', 'mp.y', 185
   def _reduce_62( val, _values, result )
  result = val
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 186
+module_eval <<'.,.,', 'mp.y', 186
   def _reduce_63( val, _values, result )
  result.push val[2]
    result
@@ -818,7 +899,7 @@ module_eval <<'.,.,', 'mailp.y', 186
 
  # reduce 66 omitted
 
-module_eval <<'.,.,', 'mailp.y', 194
+module_eval <<'.,.,', 'mp.y', 194
   def _reduce_67( val, _values, result )
                   val[1] = val[1].addr
                   result = val.join('')
@@ -828,7 +909,7 @@ module_eval <<'.,.,', 'mailp.y', 194
 
  # reduce 68 omitted
 
-module_eval <<'.,.,', 'mailp.y', 199
+module_eval <<'.,.,', 'mp.y', 199
   def _reduce_69( val, _values, result )
  result << ' ' << val[1]
    result
@@ -845,14 +926,14 @@ module_eval <<'.,.,', 'mailp.y', 199
 
  # reduce 74 omitted
 
-module_eval <<'.,.,', 'mailp.y', 210
+module_eval <<'.,.,', 'mp.y', 210
   def _reduce_75( val, _values, result )
                   @field.encrypter = val[0]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 214
+module_eval <<'.,.,', 'mp.y', 214
   def _reduce_76( val, _values, result )
                   @field.encrypter = val[0]
                   @field.keyword   = val[1]
@@ -860,7 +941,7 @@ module_eval <<'.,.,', 'mailp.y', 214
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 220
+module_eval <<'.,.,', 'mp.y', 220
   def _reduce_77( val, _values, result )
                   @field.major = val[0].to_i
                   @field.minor = val[2].to_i
@@ -868,7 +949,7 @@ module_eval <<'.,.,', 'mailp.y', 220
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 226
+module_eval <<'.,.,', 'mp.y', 226
   def _reduce_78( val, _values, result )
                   @field.main = val[0]
                   @field.sub  = val[2]
@@ -876,7 +957,7 @@ module_eval <<'.,.,', 'mailp.y', 226
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 231
+module_eval <<'.,.,', 'mp.y', 231
   def _reduce_79( val, _values, result )
                   @field.main = val[0]
                   @field.sub  = ''
@@ -886,7 +967,7 @@ module_eval <<'.,.,', 'mailp.y', 231
 
  # reduce 80 omitted
 
-module_eval <<'.,.,', 'mailp.y', 238
+module_eval <<'.,.,', 'mp.y', 238
   def _reduce_81( val, _values, result )
                   @field.params[ val[2].downcase ] = val[4]
    result
@@ -897,14 +978,14 @@ module_eval <<'.,.,', 'mailp.y', 238
 
  # reduce 83 omitted
 
-module_eval <<'.,.,', 'mailp.y', 246
+module_eval <<'.,.,', 'mp.y', 246
   def _reduce_84( val, _values, result )
                   @field.encoding = val[0]
    result
   end
 .,.,
 
-module_eval <<'.,.,', 'mailp.y', 251
+module_eval <<'.,.,', 'mp.y', 251
   def _reduce_85( val, _values, result )
                   @field.disposition = val[0]
    result
@@ -917,7 +998,7 @@ module_eval <<'.,.,', 'mailp.y', 251
 
  # reduce 88 omitted
 
-module_eval <<'.,.,', 'mailp.y', 261
+module_eval <<'.,.,', 'mp.y', 261
   def _reduce_89( val, _values, result )
                   @field.params[ val[0].downcase ] = val[2]
    result
