@@ -251,22 +251,25 @@ class Installer
 
   def do_install
     into_dir( 'bin' ) {
-      foreach_package do |dn, targ|
+      foreach_package do |targ, |
         install_bin
       end
     }
     into_dir( 'lib' ) {
-      foreach_package do |dn, targ|
+      foreach_package do |targ, topfile|
         install_rb targ
+        if topfile then
+          create_topfile targ, topfile
+        end
       end
     }
     into_dir( 'ext' ) {
-      foreach_package do |dn, targ|
+      foreach_package do |targ, |
         install_so targ
       end
     }
     into_dir( 'share' ) {
-      foreach_package do |dn, targ|
+      foreach_package do |targ, |
         install_dat targ
       end
     }
@@ -274,7 +277,7 @@ class Installer
 
   def do_clean
     into_dir( 'ext' ) {
-      foreach_package do |dn, targ|
+      foreach_package do
         clean
       end
     }
@@ -435,21 +438,11 @@ class Installer
     ret
   end
 
-  def foreach_record( fn = 'PATHCONV' )
-    File.foreach( fn ) do |line|
-      line.strip!
-      next if line.empty?
-      a = line.split(/\s+/, 3)
-      a[2] ||= '.'
-      yield a
-    end
-  end
-
   def packages
     ret = []
     FILETYPES.each do |type|
       next unless File.exist? type
-      foreach_record( "#{type}/PATHCONV") do |dir, pack, targ|
+      foreach_record( "#{type}/PATHCONV" ) do |dir, pack, |
         ret.push pack
       end
     end
@@ -458,8 +451,8 @@ class Installer
 
   def foreach_package
     path = {}
-    foreach_record do |dir, *rest|
-      path[dir] = rest
+    foreach_record( './PATHCONV' ) do |dir, pack, targ, topfile, |
+      path[dir] = [pack, targ, topfile]
     end
 
     base = File.basename( Dir.getwd )
@@ -467,14 +460,12 @@ class Installer
       next if dir[0] == ?.
       next unless File.directory? dir
 
-      unless path[dir] then
-        raise "abs path for package '#{dir}' not exist"
-      end
-      pack, targ = path[dir]
+      path[dir] or raise "abs path for package '#{dir}' not exist"
+      pack, targ, topfile = path[dir]
 
       if inclpack pack, "#{base}/#{dir}" then
         chdir( dir ) {
-          yield dir, targ
+          yield targ, topfile
         }
       else
         $stderr.puts "setup.rb: skip #{base}/#{dir}(#{pack}) by user option"
@@ -482,6 +473,16 @@ class Installer
     end
   end
 
+  def foreach_record( fname )
+    File.foreach( fname ) do |line|
+      line.strip!
+      next if line.empty?
+      a = line.split(/\s+/)
+      a[2] ||= '.'
+      yield a
+    end
+  end
+
   def inclpack( pack, dname )
     if @with.empty? then
       not @without.include? pack and
@@ -551,6 +552,14 @@ class Installer
     end
   end
 
+  def create_topfile( name, req )
+    d = isdir(@config['rb-dir'])
+    File.open( "#{d}/#{name}.rb", 'w' ) do |f|
+      f.puts "require '#{name}/#{req}'"
+    end
+    File.chmod 0644, "#{d}/#{name}.rb"
+  end
+
 
   def extconf
     # system "#{@config['ruby-path']} extconf.rb"
